.. _api-exceptions:

Exceptions API
**************

Toil specific exceptions.

.. autoexception:: toil.job::JobException
   :members:
   :noindex:

.. autoexception:: toil.job::JobGraphDeadlockException
   :members:
   :noindex:

.. autoexception:: toil.jobStores.abstractJobStore::ConcurrentFileModificationException
   :members:
   :noindex:

.. autoexception:: toil.jobStores.abstractJobStore::JobStoreExistsException
   :members:
   :noindex:

.. autoexception:: toil.jobStores.abstractJobStore::NoSuchFileException
   :members:
   :noindex:

.. autoexception:: toil.jobStores.abstractJobStore::NoSuchJobException
   :members:
   :noindex:

.. autoexception:: toil.jobStores.abstractJobStore::NoSuchJobStoreException
   :members:
   :noindex:

